"""
This submodule is responsible for making metadata about
organizations available in Python memory.

The data is stored in a CSV file that is provided with the BigBang repository.

This file was generated by a manual curation of data.
Information about this process can be found in ``organization_categories_metadata.md``
"""

import os
import pandas as pd

DOMAIN_DATA_DIR = os.path.dirname(os.path.abspath(__file__))

DOMAIN_DATA_FILENAME = "organization_categories.csv"


def load_data():
    """
    Returns a datafarme with email domains labeled by category.

    Categories include: generic, personal, company, academic, sdo

    Returns
    -------
    data: pandas.DataFrame
    """
    domain_data_path = os.path.join(DOMAIN_DATA_DIR, DOMAIN_DATA_FILENAME)
    df = pd.read_csv(
        domain_data_path,
        sep=",",
        header=0,
        index_col=False,
    )
    return df


def lookup_normalized(name, odf):
    """
    For an orgname, find the 'top level' version of that organization.
    I.e. AT&T Global Network Services Belgium SPRL -> AT&T
    """
    rows = odf[odf["name"] == name]

    if rows.shape[0] < 1:
        return None
    elif rows["subsidiary of / alias of"].isna().iloc[0]:
        return name
    else:
        for row in rows.iterrows():
            term = lookup_normalized(row[1]["subsidiary of / alias of"], odf)

            if term is not None:
                return term

    return None
